# napari-graph

Efficient graph data structures and algorithms for fast slicing, visualization, and editing.

Implementation based on the [trackmate-graph](https://github.com/mastodon-sc/mastodon/blob/master/doc/trackmate-graph.pdf).
